# Dataset of intraoperative ECoG recorded from epilepsy patients pre- and post-resection and fast ripple (FR) markings

## Summary
We present an electrophysiological dataset recorded from twenty-two subjects during resective epilepsy surgery. We used standard electrodes with 10 mm inter-contact spacing (standard ECoG) in 14 surgeries and high-density grid electrodes with 5 mm spacing (hd-ECoG) in 8 surgeries. We recorded ECoG pre- and post-resection. We detected fast ripples (FR) using a previously validated automatic detector. For each recording, we provided the recorded data and FR markings. We also provide the approximate locations of recordings and resected area. The data was used in our publication doi.org/10.1016/j.clinph.2019.07.008.

## Downloading the data

### Using gin

Create an account on gin and download the *gin* client as described [here](https://web.gin.g-node.org/G-Node/Info/wiki/gin-cli). On your computer, log in using
```bash
gin login
```

Clone the repository using:
```bash
gin get USZ_NCH/Intraoperative_ECoG_HFO    
```

Large data files will not be downloaded automatically. To get them, use
```bash
gin get-content <filename>
```

Downloaded large files will be locked (read-only). You must unlock the files using
```bash
gin unlock <filename>
```

To remove the contents of a large file again, use
```bash
gin lock <filename>
gin remove-content <filename>
```

See [here](https://web.gin.g-node.org/G-Node/Info/wiki/gin-cli+tutorial) for detailed information on how to use *gin*.


### Using git annex

Make sure git and git-annex are installed on your computer. Create an account on gin and upload your public SSH key to your gin profile. Then clone the repository using
```bash
git clone git@gin.g-node.org:/USZ_NCH/Intraoperative_ECoG_HFO .git
```

Large data files will not be downloaded automatically. To get them, use
```bash
git annex get <filename>
```

Downloaded large files will be locked (read-only). You must unlock the files using
```bash
git annex unlock <filename>
```

To remove the contents of a large file again, use
```bash
git annex --force lock <filename>
git annex drop <filename>
```

See the *git annex* documentation for details.


### Using the web browser

xxDownload the latest release as a zip file by clicking on *Releases* on the main page at https://gin.g-node.org/USZ_NCH/Intraoperative_ECoG_HFO . This zip file will contain all small (text) files only, while large data files will not be downloaded automatically and an empty placeholder will be put in their place. To get the full content of such a large file , download these files individually as needed from the web interface by clicking on them in the repository browser.

## Repository structure

### Directory datasets
xx

### Directory datasets_matlab
xx

### Directory code
Contains example code to help in loading and analyzing the data. The file `xxexamply.py` is a Python script that acts as a tutorial for loading and plotting data. The scripts `xx reproduce the plots of the data found  in the publication. The files `neo_utils.py` and `odml_utils.py` contain useful utility routines to work with data and metadata. Finally, the file `example.m` contains a rudimentary MATLAB script demonstrating how to use the data provided in the .hd5 files.

To run the Python example code, download the release of this repository, and install the requirements in `code/requirements.txt`xx. Then, run the example via
```
   cd code
   python example.pyxx
```
The script produces a figure saved in three different graphics file formats.

### Directory code/xx
xx

### Further subdirectories of code
The subdirectories `python-neo`, `python-odml`, and `elephant` contain snapshots of the Neo[1], odML[2], and Elephant[3] libraries, respectively, that are required by the example scripts and the xx loading routine. odML provides an API to handle the metadata files.
* [1] https://github.com/G-Node/python-odml


## Updates
Updated versions of the codes will be provided at:
https://gin.g-node.org/USZ_NCH/Intraoperative_ECoG_HFO 
This includes, in particular, xx

## Related Publications
* Boran Ece, Ramantani G, Krayenbühl N, Schreiber M, König K, Fedele T, Sarnthein J. High-density ECoG improves the detection of high frequency oscillations that predict seizure outcome. Clinph. doi.org/10.1016/j.clinph.2019.07.008
* Prediction of seizure outcome improved by fast ripples detected in low-noise intraoperative corticogram.
* Automatic detection of high frequency oscillations during epilepsy surgery predicts seizure outcome.
	
	
## Licensing
<a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br /><span xmlns:dct="http://purl.org/dc/terms/" property="dct:title">Dataset of simultaneous scalp EEG and intracranial EEG recordings and human medial temporal lobe units during a verbal working memory task</span> in the directories `xxdatasets` and `datasets_matlab` by <span xmlns:cc="http://creativecommons.org/ns#" property="cc:attributionName"> xxx </span> is licensed under a <a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.

<a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-sa/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.

xxxAll code in the directories `code`, `code/python-odml`, are each published under the BSD 3 clause licenses. See the `LICENSE.txt` or `LICENSE` files in the corresponding directories for the full license.


